@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: MmapFileWriter.h 2035 2006-11-23 16:14:21Z svn $
+ * $Id: MmapFileWriter.h 2162 2006-12-03 14:36:10Z svn $
  *****************************************************************************/
 
 #ifndef MMAP_FILE_WRITER_H
@@ -44,7 +44,7 @@ using namespace std;
 class MmapFileWriter: public FileWriter
 {
 public:
-    static const apr_int32_t OPEN_FLAG;
+    static const apr_int32_t OPEN_FLAG  = APR_READ|APR_WRITE|APR_BINARY;
     /**
      * コンストラクタ．
      *
