@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: PostDataChecker.h 2264 2006-12-14 14:25:43Z svn $
+ * $Id: PostDataChecker.h 2264M 2006-12-16 09:54:56Z (ローカル) $
  *****************************************************************************/
 
 #ifndef POST_DATA_CHECKER_H
@@ -46,7 +46,7 @@ class PostDataChecker: public Uncopyable
 {
 public:
     static void validate_uitem(apr_pool_t *pool, apr_off_t file_size,
-                               apr_time_t  mtime, const char *file_name,
+                               apr_time_t  mtime, const char **file_name,
                                const char **file_mime, const char *file_digest,
                                const char *remove_pass,
                                const char *download_pass,
@@ -54,7 +54,8 @@ public:
 private:
     static const char HTML_EXT[];
 
-    static void validate_file_name(const char *file_name);
+    static void validate_file_name(apr_pool_t *pool, const char **file_name);
+    static void validate_comment(apr_pool_t *pool, const char **comment);
     static void validate_file_ext(const char *file_ext);
 };
 
