@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ReadLocker.h 2061 2006-11-24 12:48:10Z svn $
+ * $Id: ReadLocker.h 2256 2006-12-13 10:28:14Z svn $
  *****************************************************************************/
 
 #ifndef READ_LOCKER_H
@@ -68,12 +68,13 @@ public:
                 continue;
             }
 
+            MEMORY_BARRIER;
             return;
         }
     };
     ~ReadLocker()
     {
-        apr_atomic_dec(read_count_);
+        (void)apr_atomic_dec(read_count_);
     };
     static bool is_locked(apr_atomic_t *read_count) {
         return apr_atomic_read(read_count) != 0;
