@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItem.h 2202 2006-12-09 15:18:21Z svn $
+ * $Id: UploadItem.h 2242 2006-12-11 15:35:40Z svn $
  *****************************************************************************/
 
 #ifndef UPLOAD_ITEM_H
@@ -155,7 +155,7 @@ public:
     }
     void increment_download_count()
     {
-        apr_atomic_inc(&(header_.download_count));
+        (void)apr_atomic_inc(&(header_.download_count));
         header_.is_need_sync = true;
     }
     /**
