@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: WriteLocker.h 2193 2006-12-09 01:26:55Z svn $
+ * $Id: WriteLocker.h 2256 2006-12-13 10:28:14Z svn $
  *****************************************************************************/
 
 #ifndef WRITE_LOCKER_H
@@ -61,10 +61,11 @@ public:
         } else {
             lock();
         }
+        MEMORY_BARRIER;
     };
     ~WriteLocker()
     {
-        apr_atomic_set(read_count_, 0);
+        (void)apr_atomic_set(read_count_, 0);
     };
     static bool is_locked(apr_atomic_t *read_count) {
         return apr_atomic_read(read_count) == ReadWriteLocker::WRITE_LOCKED;
