@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: PostDataChecker.cpp 2264 2006-12-14 14:25:43Z svn $
+ * $Id: PostDataChecker.cpp 2264M 2006-12-16 10:56:55Z (ローカル) $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -30,12 +30,13 @@
 #include <cstring>
 
 #include "PostDataChecker.h"
+#include "CharCodeConverter.h"
 #include "Auxiliary.h"
 #include "Message.h"
 #include "Macro.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: PostDataChecker.cpp 2264 2006-12-14 14:25:43Z svn $");
+SOURCE_INFO_ADD("$Id: PostDataChecker.cpp 2264M 2006-12-16 10:56:55Z (ローカル) $");
 
 const char PostDataChecker::HTML_EXT[]      = "htm";
 
@@ -43,7 +44,7 @@ const char PostDataChecker::HTML_EXT[]      = "htm";
  * public メソッド
  *****************************************************************************/
 void PostDataChecker::validate_uitem(apr_pool_t *pool, apr_off_t file_size,
-                                     apr_time_t  mtime, const char *file_name,
+                                     apr_time_t  mtime, const char **file_name,
                                      const char **file_mime,
                                      const char *file_digest,
                                      const char *remove_pass,
@@ -51,15 +52,15 @@ void PostDataChecker::validate_uitem(apr_pool_t *pool, apr_off_t file_size,
                                      const char **comment)
 {
     const char *file_ext;
-    apr_size_t escaped_length;
 
-    validate_file_name(file_name);
-    file_ext = get_file_ext(file_name);
+    validate_file_name(pool, file_name);
+    validate_comment(pool, comment);
+    file_ext = get_file_ext(*file_name);
     validate_file_ext(file_ext);
 
-    if (strlen(file_name) == 0) {
+    if (strlen(*file_name) == 0) {
         THROW(MESSAGE_POST_FILE_NAME_EMPTY);
-    } else if (strlen(file_name) > (ITM_MAX_FILE_NAME_SIZE-1)) {
+    } else if (strlen(*file_name) > (ITM_MAX_FILE_NAME_SIZE-1)) {
         THROW(MESSAGE_POST_FILE_NAME_TOO_LONG);
     }
     if (file_size == 0) {
@@ -87,8 +88,6 @@ void PostDataChecker::validate_uitem(apr_pool_t *pool, apr_off_t file_size,
         THROW(MESSAGE_POST_DOWNLOAD_PASS_TOO_LONG);
     }
 
-    escape_html(pool, *comment, strlen(*comment), comment, &escaped_length);
-
     if (strlen(*comment) == 0) {
 #ifndef EMPTY_COMMENT
         THROW(MESSAGE_POST_COMMENT_EMPTY);
@@ -98,21 +97,39 @@ void PostDataChecker::validate_uitem(apr_pool_t *pool, apr_off_t file_size,
     }
 }
 
-void PostDataChecker::validate_file_name(const char *file_name)
+
+/******************************************************************************
+ * public メソッド
+ *****************************************************************************/
+void PostDataChecker::validate_file_name(apr_pool_t *pool,
+                                         const char **file_name)
 {
-    for (; *file_name != '\0'; file_name++) {
-        if ((*file_name == '<') || (*file_name == '>') ||
-            (*file_name == '"') || (*file_name == '\'') ||
-            (*file_name == '\r') || (*file_name == '\n') ||
-            (*file_name == '\\')) {
+    // 不正なシーケンスを排除
+    *file_name = CharCodeConverter::convert(pool, *file_name,
+                                            SYS_CHARACTER_CODE,
+                                            SYS_CHARACTER_CODE);
+
+    for (const char *name = *file_name; *name != '\0'; name++) {
+        if ((*name == '<') || (*name == '>') || (*name == '"') ||
+            (*name == '\'') || (*name == '\r') || (*name == '\n') ||
+            (*name == '\\')) {
             THROW(MESSAGE_POST_FILE_NAME_INVALID);
         }
     }
 }
 
-/******************************************************************************
- * public メソッド
- *****************************************************************************/
+void PostDataChecker::validate_comment(apr_pool_t *pool, const char **comment)
+{
+    apr_size_t escaped_length;
+
+    // 不正なシーケンスを排除
+    *comment = CharCodeConverter::convert(pool, *comment,
+                                          SYS_CHARACTER_CODE,
+                                          SYS_CHARACTER_CODE);
+
+    escape_html(pool, *comment, strlen(*comment), comment, &escaped_length);
+}
+
 void PostDataChecker::validate_file_ext(const char *file_ext)
 {
     if (strncmp(file_ext, HTML_EXT, LITERAL_STRLEN(HTML_EXT)) == 0) {
