@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: PostProgressList.cpp 2216 2006-12-09 20:49:51Z svn $
+ * $Id: PostProgressList.cpp 2253 2006-12-13 06:00:05Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -30,10 +30,11 @@
 #include <iomanip>
 
 #include "PostProgressList.h"
+#include "ReadLocker.h"
 #include "WriteLocker.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: PostProgressList.cpp 2216 2006-12-09 20:49:51Z svn $");
+SOURCE_INFO_ADD("$Id: PostProgressList.cpp 2253 2006-12-13 06:00:05Z svn $");
 
 const apr_uint32_t PostProgressList::ID_DUMMY   = 0;
 const apr_time_t PostProgressList::ENTRY_UNUSED = 0;
@@ -45,7 +46,7 @@ const apr_time_t PostProgressList::ENTRY_USED   = 1;
 PostProgressList::PostProgressList()
 {
     memset(progress_list_, 0, sizeof(progress_list_));
-    apr_atomic_set(&lock_, ReadWriteLocker::NOT_LOCKER);
+    (void)apr_atomic_set(&lock_, ReadWriteLocker::NOT_LOCKER);
 }
 
 RequestReader::post_progress_t *PostProgressList::get(apr_uint32_t upload_id)
