@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ThumbnailList.cpp 2201 2006-12-09 02:51:13Z svn $
+ * $Id: ThumbnailList.cpp 2255 2006-12-13 09:05:01Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -37,7 +37,7 @@
 #include "Auxiliary.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: ThumbnailList.cpp 2201 2006-12-09 02:51:13Z svn $");
+SOURCE_INFO_ADD("$Id: ThumbnailList.cpp 2255 2006-12-13 09:05:01Z svn $");
 
 #define AS_THUMBNAIL_LIST(pointer)  reinterpret_cast<ThumbnailList *>(pointer)
 
@@ -46,6 +46,7 @@ SOURCE_INFO_ADD("$Id: ThumbnailList.cpp 2201 2006-12-09 02:51:13Z svn $");
  *****************************************************************************/
 ThumbnailList::ThumbnailList(apr_shm_t *shm, apr_size_t max_list_size)
   : thumbnail_list_(0),
+    thumbnail_list_size_(0),
     max_list_size_(max_list_size)
 {
 #ifdef DEBUG
@@ -55,52 +56,56 @@ ThumbnailList::ThumbnailList(apr_shm_t *shm, apr_size_t max_list_size)
 #endif
 
     init_shm();
-
-    *thumbnail_list_size_ = 0;
 }
 
 void ThumbnailList::add(apr_size_t item_id)
 {
     apr_size_t i;
+    apr_size_t thumbnail_list_size;
+
+    thumbnail_list_size = size();
 
     // MEMO: thumbnail_list_ は item_id に基づいて降順に並んでいる
 
     i = get_insert_index(item_id);
-    if (i == *thumbnail_list_size_) {
-        if (*thumbnail_list_size_ == max_list_size_) { // 追加する必要なし
+    if (i == thumbnail_list_size) {
+        if (thumbnail_list_size == max_list_size_) { // 追加する必要なし
             return;
         } else { // 末尾に追加
             thumbnail_list_[i] = item_id;
         }
     } else { // 挿入
         memmove(thumbnail_list_ + i + 1, thumbnail_list_ + i,
-                sizeof(apr_size_t) * (*thumbnail_list_size_ - i));
+                sizeof(apr_size_t) * (thumbnail_list_size - i));
         thumbnail_list_[i] = item_id;
     }
 
-    (*thumbnail_list_size_)++;
+    thumbnail_list_size_++;
 }
 
 void ThumbnailList::remove(apr_size_t item_id)
 {
     apr_size_t i;
+    apr_size_t thumbnail_list_size;
+
+    thumbnail_list_size = size();
 
     i = get_index_by_id(item_id);
-    if (i == *thumbnail_list_size_) {
+    if (i == thumbnail_list_size) {
         // リスト中に存在しない
         return;
     }
 
-    if (i != (*thumbnail_list_size_ - 1)) {
+    if (i != (thumbnail_list_size - 1)) {
         memmove(thumbnail_list_ + i, thumbnail_list_ + i + 1,
-                sizeof(apr_size_t) * (*thumbnail_list_size_ - i - 1));
+                sizeof(apr_size_t) * (thumbnail_list_size - i - 1));
     }
 
-    if (*thumbnail_list_size_ == 0) { // 念のため
+    if (thumbnail_list_size == 0) { // 念のため
         THROW(MESSAGE_BUG_FOUND);
     }
 
-    (*thumbnail_list_size_)--;
+    thumbnail_list_size_--;
 }
 
 ThumbnailList *ThumbnailList::get_instance(apr_shm_t *shm,
@@ -126,8 +131,7 @@ ThumbnailList *ThumbnailList::child_init(apr_shm_t *shm)
 
 apr_size_t ThumbnailList::get_memory_size(apr_size_t max_list_size)
 {
-    return sizeof(ThumbnailList) +
-        (sizeof(apr_size_t)*max_list_size) + sizeof(apr_size_t);
+    return sizeof(ThumbnailList) + (sizeof(apr_size_t)*max_list_size);
 }
 
 #include <fstream>
@@ -135,7 +139,10 @@ apr_size_t ThumbnailList::get_memory_size(apr_size_t max_list_size)
 void ThumbnailList::dump_thumbnail_list(apr_pool_t *pool,
                                         ThumbnailList *list)
 {
-    for (apr_size_t i = 0; i < *(list->thumbnail_list_size_); i++) {
+    apr_size_t size;
+
+    size = list->size();
+    for (apr_size_t i = 0; i < size; i++) {
         cerr << "[" << setw(3) << i << "] ";
         cerr << list->thumbnail_list_[i] << endl;
     }
@@ -153,12 +160,11 @@ void ThumbnailList::child_init_impl()
 void ThumbnailList::init_shm()
 {
     thumbnail_list_ = AS_SIZE(this + 1);
-    thumbnail_list_size_ = AS_SIZE(thumbnail_list_ + max_list_size_);
 
 #ifdef __INTEL_COMPILER
 #pragma warning(disable:1684)
 #endif
-    ASSERT_EQUAL(AS_CHAR(thumbnail_list_size_ + 1),
+    ASSERT_EQUAL(AS_CHAR(thumbnail_list_ + max_list_size_),
                  AS_CHAR(thumbnail_list_) +
                  (get_memory_size(max_list_size_) - sizeof(ThumbnailList)));
 #ifdef __INTEL_COMPILER
@@ -174,8 +180,11 @@ void ThumbnailList::attach_shm()
 apr_size_t ThumbnailList::get_insert_index(apr_size_t item_id) const
 {
     apr_size_t i;
+    apr_size_t thumbnail_list_size;
 
-    for (i = 0; i < *thumbnail_list_size_; i++) {
+    thumbnail_list_size = size();
+
+    for (i = 0; i < thumbnail_list_size; i++) {
         if (item_id >= thumbnail_list_[i]) {
             return i;
         }
@@ -185,13 +194,17 @@ apr_size_t ThumbnailList::get_insert_index(apr_size_t item_id) const
 
 apr_size_t ThumbnailList::get_index_by_id(apr_size_t item_id) const
 {
+    apr_size_t thumbnail_list_size;
+
+    thumbnail_list_size = size();
+
     // 頻繁には呼ばれ無いはずなので，線形探索...
-    for (apr_size_t i = 0; i < *thumbnail_list_size_; i++) {
+    for (apr_size_t i = 0; i < thumbnail_list_size; i++) {
         if (thumbnail_list_[i] == item_id) {
             return i;
         }
     }
-    return *thumbnail_list_size_;
+    return thumbnail_list_size;
 }
 
 // Local Variables:
