@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItem.cpp 2264 2006-12-14 14:25:43Z svn $
+ * $Id: UploadItem.cpp 2264M 2006-12-16 10:04:04Z (ローカル) $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -40,7 +40,7 @@
 #include "Auxiliary.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: UploadItem.cpp 2264 2006-12-14 14:25:43Z svn $");
+SOURCE_INFO_ADD("$Id: UploadItem.cpp 2264M 2006-12-16 10:04:04Z (ローカル) $");
 
 #define AS_BCOMMENT(pointer)        reinterpret_cast<bbs_comment_t *>(pointer)
 #define UINT16(pointer)             static_cast<apr_uint16_t>(pointer)
@@ -72,7 +72,7 @@ UploadItem *UploadItem::get_instance(void *memory, apr_size_t item_id,
 
     if (is_need_validate) {
         PostDataChecker::validate_uitem(temp_pool.get(), file_size, mtime,
-                                        file_name, &file_mime, file_digest,
+                                        &file_name, &file_mime, file_digest,
                                         remove_pass, download_pass, &comment);
     }
 
