@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemList.cpp 2201 2006-12-09 02:51:13Z svn $
+ * $Id: UploadItemList.cpp 2255 2006-12-13 09:05:01Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -38,7 +38,7 @@
 #include "Auxiliary.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: UploadItemList.cpp 2201 2006-12-09 02:51:13Z svn $");
+SOURCE_INFO_ADD("$Id: UploadItemList.cpp 2255 2006-12-13 09:05:01Z svn $");
 
 #define AS_UHEADER(pointer)     reinterpret_cast<UploadItem::header_t *>(pointer)
 #define AS_UITEM_LIST(pointer)  reinterpret_cast<UploadItemList *>(pointer)
@@ -49,6 +49,8 @@ SOURCE_INFO_ADD("$Id: UploadItemList.cpp 2201 2006-12-09 02:51:13Z svn $");
 UploadItemList::UploadItemList(apr_shm_t *shm, apr_uint64_t max_file_size,
                                apr_size_t max_list_size)
   : header_list_(0),
+    header_list_size_(0),
+    total_file_size_(0),
     max_file_size_(max_file_size),
     max_list_size_(max_list_size)
 {
@@ -59,33 +61,33 @@ UploadItemList::UploadItemList(apr_shm_t *shm, apr_uint64_t max_file_size,
 #endif
 
     init_shm();
-
-    *header_list_size_ = 0;
-    *total_file_size_ = 0;
 }
 
 void UploadItemList::add(UploadItem *uitem)
 {
     apr_size_t i;
+    apr_size_t header_list_size;
 
     // MEMO: header_list_ は mtime に基づいて降順に並んでいる
 
+    header_list_size = size();
+
     i = get_insert_index(uitem);
 
-    if (i == *header_list_size_) {
-        if (*header_list_size_ == max_list_size_) { // 追加する必要なし
+    if (i == header_list_size) {
+        if (header_list_size == max_list_size_) { // 追加する必要なし
             return;
         } else { // 末尾に追加
-            load_header(uitem, header_list_ + *header_list_size_);
+            load_header(uitem, header_list_ + header_list_size);
         }
     } else { // 挿入
         memmove(header_list_ + i + 1, header_list_ + i,
-                sizeof(UploadItem::header_t) * (*header_list_size_ - i));
+                sizeof(UploadItem::header_t) * (header_list_size - i));
         load_header(uitem, header_list_ + i);
     }
 
-    (*total_file_size_) += uitem->get_file_size();
-    (*header_list_size_)++;
+    total_file_size_ += uitem->get_file_size();
+    header_list_size_++;
 }
 
 void UploadItemList::remove(apr_size_t item_id)
@@ -93,23 +95,26 @@ void UploadItemList::remove(apr_size_t item_id)
     apr_size_t i;
     apr_off_t file_size;
     UploadItem::header_t *header;
+    apr_size_t header_list_size;
+
+    header_list_size = size();
 
     i = get_index_by_id(item_id);
     header = get_by_index(i);
 
     file_size = header->file_size;
 
-    if (i != (*header_list_size_ - 1)) {
+    if (i != (header_list_size - 1)) {
         memmove(header_list_ + i, header_list_ + i + 1,
-                sizeof(UploadItem::header_t) * (*header_list_size_ - i - 1));
+                sizeof(UploadItem::header_t) * (header_list_size - i - 1));
     }
 
-    if (*header_list_size_ == 0) { // 念のため
+    if (header_list_size == 0) { // 念のため
         THROW(MESSAGE_BUG_FOUND);
     }
 
-    (*total_file_size_) -= file_size;
-    (*header_list_size_)--;
+    total_file_size_ -= file_size;
+    header_list_size_--;
 }
 
 UploadItemList *UploadItemList::get_instance(apr_shm_t *shm,
@@ -137,14 +142,16 @@ UploadItemList *UploadItemList::child_init(apr_shm_t *shm)
 apr_size_t UploadItemList::get_memory_size(apr_size_t max_list_size)
 {
     return sizeof(UploadItemList) +
-        (sizeof(UploadItem::header_t)*max_list_size) +
-        sizeof(apr_size_t) + sizeof(apr_off_t);
+        (sizeof(UploadItem::header_t)*max_list_size);
 }
 
 void UploadItemList::dump_header_list(apr_pool_t *pool,
                                       UploadItemList *list)
 {
-    for (apr_size_t i = 0; i < *(list->header_list_size_); i++) {
+    apr_size_t size;
+
+    size = list->size();
+    for (apr_size_t i = 0; i < size; i++) {
         dump_header(pool, list->header_list_ + i);
     }
 }
@@ -161,13 +168,11 @@ void UploadItemList::child_init_impl()
 void UploadItemList::init_shm()
 {
     header_list_ = AS_UHEADER(this + 1);
-    header_list_size_ = AS_SIZE(header_list_ + max_list_size_);
-    total_file_size_ = AS_OFF(header_list_size_ + 1);
 
 #ifdef __INTEL_COMPILER
 #pragma warning(disable:1684)
 #endif
-    ASSERT_EQUAL(AS_CHAR(total_file_size_ + 1),
+    ASSERT_EQUAL(AS_CHAR(header_list_ + max_list_size_),
                  AS_CHAR(header_list_) +
                  (get_memory_size(max_list_size_) - sizeof(UploadItemList)));
 #ifdef __INTEL_COMPILER
@@ -183,8 +188,11 @@ void UploadItemList::attach_shm()
 apr_size_t UploadItemList::get_insert_index(UploadItem *uitem) const
 {
     apr_size_t i;
+    apr_size_t header_list_size;
 
-    for (i = 0; i < *header_list_size_; i++) {
+    header_list_size = size();
+
+    for (i = 0; i < header_list_size; i++) {
         if (uitem->get_mtime() >= header_list_[i].mtime) {
             return i;
         }
@@ -194,8 +202,12 @@ apr_size_t UploadItemList::get_insert_index(UploadItem *uitem) const
 
 apr_size_t UploadItemList::get_index_by_id(apr_size_t item_id) const
 {
+    apr_size_t header_list_size;
+
+    header_list_size = size();
+
     // 頻繁には呼ばれ無いはずなので，線形探索...
-    for (apr_size_t i = 0; i < *header_list_size_; i++) {
+    for (apr_size_t i = 0; i < header_list_size; i++) {
         if ((header_list_ + i)->id == item_id) {
             return i;
         }
