@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploaderConfig.cpp 2179 2006-12-07 12:47:20Z svn $
+ * $Id: UploaderConfig.cpp 2199 2006-12-09 02:45:03Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -37,14 +37,16 @@
 #include "UploadItemManager.h"
 #include "UploadItemListReader.h"
 #include "ThumbnailList.h"
+#include "DownloadFlowController.h"
 #include "PostFlowController.h"
+#include "PostProgressList.h"
 #include "UploaderTemplate.h"
 #include "Macro.h"
 #include "Auxiliary.h"
 #include "Message.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: UploaderConfig.cpp 2179 2006-12-07 12:47:20Z svn $");
+SOURCE_INFO_ADD("$Id: UploaderConfig.cpp 2199 2006-12-09 02:45:03Z svn $");
 
 #define PARAM_PREFIX "Uploader"
 
@@ -128,7 +130,9 @@ UploaderConfig::UploaderConfig(apr_pool_t *pool)
     item_list_shm_(NULL),
     thumbnail_list_shm_(NULL),
     item_manager_shm_(NULL),
-    flow_controller_shm_(NULL),
+    download_flow_controller_shm_(NULL),
+    post_flow_controller_shm_(NULL),
+    post_progress_list_shm_(NULL),
     item_list_(NULL),
     thumbnail_list_(NULL),
     item_manager_(NULL)
@@ -154,8 +158,12 @@ void UploaderConfig::init()
     thumbnail_list_shm_ = create_shm
         (pool_, ThumbnailList::get_memory_size(total_file_number_limit));
     item_manager_shm_ = create_shm(pool_, UploadItemManager::get_memory_size());
-    flow_controller_shm_ = create_shm(pool_,
-                                      PostFlowController::get_memory_size());
+    download_flow_controller_shm_ = create_shm
+        (pool_, DownloadFlowController::get_memory_size());
+    post_flow_controller_shm_ = create_shm
+        (pool_, PostFlowController::get_memory_size());
+    post_progress_list_shm_ = create_shm
+        (pool_, PostProgressList::get_memory_size());
 
     thumbnail_list_ = ThumbnailList::get_instance(thumbnail_list_shm_,
                                                   total_file_number_limit);
@@ -170,8 +178,12 @@ void UploaderConfig::init()
                                                     thumb_dir_path);
     item_manager_->init(item_list_, thumbnail_list_);
 
-    flow_controller_ = PostFlowController::get_instance(flow_controller_shm_,
-                                                        PST_INTERVAL_SEC);
+    download_flow_controller_ = DownloadFlowController::get_instance
+        (download_flow_controller_shm_);
+    post_flow_controller_ = PostFlowController::get_instance
+        (post_flow_controller_shm_, PST_INTERVAL_SEC);
+    post_progress_list_ = PostProgressList::get_instance
+        (post_progress_list_shm_);
 
     is_active_ = true;
 }
@@ -185,7 +197,9 @@ void UploaderConfig::child_init()
     attach_shm(pool_, item_list_shm_);
     attach_shm(pool_, thumbnail_list_shm_);
     attach_shm(pool_, item_manager_shm_);
-    attach_shm(pool_, flow_controller_shm_);
+    attach_shm(pool_, download_flow_controller_shm_);
+    attach_shm(pool_, post_flow_controller_shm_);
+    attach_shm(pool_, post_progress_list_shm_);
 
     item_list_ = UploadItemList::child_init(item_list_shm_);
     thumbnail_list_ = ThumbnailList::child_init(thumbnail_list_shm_);
@@ -201,7 +215,9 @@ void UploaderConfig::finalize()
 
     item_manager_->sync_all_item(pool_);
 
-    apr_shm_destroy(flow_controller_shm_);
+    apr_shm_destroy(download_flow_controller_shm_);
+    apr_shm_destroy(post_flow_controller_shm_);
+    apr_shm_destroy(post_progress_list_shm_);
     apr_shm_destroy(item_manager_shm_);
     apr_shm_destroy(thumbnail_list_shm_);
     apr_shm_destroy(item_list_shm_);
