@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: mod_uploader.cpp 2168 2006-12-03 20:56:04Z svn $
+ * $Id: mod_uploader.cpp 2179 2006-12-07 12:47:20Z svn $
  *****************************************************************************/
 
 /**
@@ -56,7 +56,7 @@
 #define RESPONSE_TYPE_APACHE
 #include "uploader_handler.cpp"
 
-SOURCE_INFO_ADD("$Id: mod_uploader.cpp 2168 2006-12-03 20:56:04Z svn $");
+SOURCE_INFO_ADD("$Id: mod_uploader.cpp 2179 2006-12-07 12:47:20Z svn $");
 
 static const char *HANDLER_NAME = "uploader";
 
@@ -265,6 +265,7 @@ TEMPLATE_DIRECTIVE_HANDLER(PROGRESS_VIEW, apr_pstrdup(parms->pool, arg));
 TEMPLATE_DIRECTIVE_HANDLER(DOWNLOAD_VIEW, apr_pstrdup(parms->pool, arg));
 TEMPLATE_DIRECTIVE_HANDLER(THUMBNAIL_VIEW, apr_pstrdup(parms->pool, arg));
 TEMPLATE_DIRECTIVE_HANDLER(ADMIN_VIEW, apr_pstrdup(parms->pool, arg));
+TEMPLATE_DIRECTIVE_HANDLER(ERROR_VIEW, apr_pstrdup(parms->pool, arg));
 
 static const command_rec uploader_cmds[] = {
     DIRECTIVE_ENTRY(BASE_URL, base_url),
@@ -283,6 +284,7 @@ static const command_rec uploader_cmds[] = {
     DIRECTIVE_ENTRY(DOWNLOAD_VIEW_TEMPLATE, DOWNLOAD_VIEW),
     DIRECTIVE_ENTRY(THUMBNAIL_VIEW_TEMPLATE, THUMBNAIL_VIEW),
     DIRECTIVE_ENTRY(ADMIN_VIEW_TEMPLATE, ADMIN_VIEW),
+    DIRECTIVE_ENTRY(ERROR_VIEW_TEMPLATE, ERROR_VIEW),
     { NULL }
 };
 
