@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: uploader_handler.cpp 2220 2006-12-10 06:10:27Z svn $
+ * $Id: uploader_handler.cpp 2247 2006-12-13 03:32:32Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -56,7 +56,7 @@
 #include "SourceInfo.h"
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2220 2006-12-10 06:10:27Z svn $");
+SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2247 2006-12-13 03:32:32Z svn $");
 #endif
 
 #define IS_REQUEST_COMMAND(arg, command) \
@@ -672,6 +672,9 @@ static int download(typename Response::Handle *r, UploaderConfig *config,
             if ((strlen(uitem->get_download_pass()) != 0) &&
                 (strncmp(uitem->get_download_pass(), download_pass,
                          strlen(uitem->get_download_pass())) != 0)) {
+                if (strlen(download_pass) != 0) {
+                    THROW(MESSAGE_DOWNLOAD_PASS_MISMATCH);
+                }
                 return input_pass<Response>(r, config, uitem);
             }
         }
@@ -766,7 +769,10 @@ static int remove(typename Response::Handle *r, UploaderConfig *config,
         uitem = config->get_item_manager()->get_item(r->pool, item_id);
 
         if (!is_admin_mode) {
-            if ((strlen(uitem->get_remove_pass()) == 0) ||
+            if (
+#ifndef EMPTY_PASSWORD
+                (strlen(uitem->get_remove_pass()) == 0) ||
+#endif
                 (strncmp(remove_pass, uitem->get_remove_pass(),
                          strlen(uitem->get_remove_pass())) != 0)) {
                 THROW(MESSAGE_REMOVE_PASS_MISMATCH);
@@ -941,7 +947,7 @@ int uploader_command_handler(typename Response::Handle *r, UploaderConfig *confi
     const char *request_uri;
 
     if (UNLIKELY(strlen(arg) > HDL_MAX_PATH_INFO_SIZE)) {
-        THROW(MESSAGE_HNDL_PATH_INFO_TOO_LONG);
+        THROW(MESSAGE_HANDLER_PATH_INFO_TOO_LONG);
     }
 
     if (UNLIKELY(*arg == '\0')) {
