@@ -64,6 +64,10 @@ namespace UploaderConfig
             buffer.AppendFormat("UploaderErrorViewTemplate      \"{0}\"\r\n",
                 uploaderConfig.errorTmplPath);
 
+            appendAccess(buffer, uploaderConfig.imageDirPath);
+            appendAccess(buffer, uploaderConfig.stylesheetDirPath);
+            appendAccess(buffer, uploaderConfig.javascriptDirPath);
+
             buffer.AppendFormat("Alias /up_img                  \"{0}\"\r\n",
                 uploaderConfig.imageDirPath);
             buffer.AppendFormat("Alias /up_css                  \"{0}\"\r\n",
@@ -75,5 +79,19 @@ namespace UploaderConfig
 
             return buffer.ToString();
         }
+
+        private static void appendAccess(StringBuilder buffer, string path)
+        {
+            string unixPath;
+
+            // Ȃł null `FbNKvȂ̂킩Ėł...
+            // ŕKvȂقɂKvǂȂDvpeB݁H
+            unixPath = (path == null) ? "" : path.Replace('\\', '/');
+
+            buffer.AppendFormat("<Directory \"{0}\">\r\n", unixPath);
+            buffer.AppendFormat("    Order Allow,Deny\r\n");
+            buffer.AppendFormat("    Allow From All\r\n");
+            buffer.AppendFormat("</Directory>\r\n");
+        }
     }
 }
